﻿/**
 *定义的网络模块
 */
(function($){
    /*   sha1函数实现
     *   A   JavaScript   implementation   of   the   Secure   Hash   Algorithm,   SHA-1,   as   defined
     *   in   FIPS   PUB   180-1
     *   Version   2.1-BETA   Copyright   Paul   Johnston   2000   -   2002.
     *   Other   contributors:   Greg   Holt,   Andrew   Kepert,   Ydnar,   Lostinet
     *   Distributed   under   the   BSD   License
     *   See   http://pajhome.org.uk/crypt/md5   for   details.
     */
    /*
     *   Configurable   variables.   You   may   need   to   tweak   these   to   be   compatible   with
     *   the   server-side,   but   the   defaults   work   in   most   cases.
     */
    var hexcase = 0;
    /*   hex   output   format.   0   -   lowercase;   1   -   uppercase                 */
    var b64pad = "";
    /*   base-64   pad   character.   "="   for   strict   RFC   compliance       */
    var chrsz = 8;
    /*   bits   per   input   character.   8   -   ASCII;   16   -   Unicode             */
    /*
     *   These   are   the   functions   you'll   usually   want   to   call
     *   They   take   string   arguments   and   return   either   hex   or   base-64   encoded   strings
     */
    function hex_sha1(s) {
        return binb2hex(core_sha1(str2binb(s), s.length * chrsz));
    }

    function b64_sha1(s) {
        return binb2b64(core_sha1(str2binb(s), s.length * chrsz));
    }

    function str_sha1(s) {
        return binb2str(core_sha1(str2binb(s), s.length * chrsz));
    }

    function hex_hmac_sha1(key, data) {
        return binb2hex(core_hmac_sha1(key, data));
    }

    function b64_hmac_sha1(key, data) {
        return binb2b64(core_hmac_sha1(key, data));
    }
    
    function str_hmac_sha1(key, data) {
        return binb2str(core_hmac_sha1(key, data));
    }
    /*
     *   Perform   a   simple   self-test   to   see   if   the   VM   is   working
     */
    function sha1_vm_test() {
        return hex_sha1("abc") == "a9993e364706816aba3e25717850c26c9cd0d89d";
    }

    /*
     *   Calculate   the   SHA-1   of   an   array   of   big-endian   words,   and   a   bit   length
     */
    function core_sha1(x, len) {
        /*   append   padding   */
        x[len >> 5] |= 0x80 << (24 - len % 32);
        x[((len + 64 >> 9) << 4) + 15] = len;

        var w = Array(80);
        var a = 1732584193;
        var b = -271733879;
        var c = -1732584194;
        var d = 271733878;
        var e = -1009589776;

        for (var i = 0; i < x.length; i += 16) {
            var olda = a;
            var oldb = b;
            var oldc = c;
            var oldd = d;
            var olde = e;

            for (var j = 0; j < 80; j++) {
                if (j < 16)
                    w[j] = x[i + j];
                else
                    w[j] = rol(w[j - 3] ^ w[j - 8] ^ w[j - 14] ^ w[j - 16], 1);
                var t = safe_add(safe_add(rol(a, 5), sha1_ft(j, b, c, d)), safe_add(safe_add(e, w[j]), sha1_kt(j)));
                e = d;
                d = c;
                c = rol(b, 30);
                b = a;
                a = t;
            }

            a = safe_add(a, olda);
            b = safe_add(b, oldb);
            c = safe_add(c, oldc);
            d = safe_add(d, oldd);
            e = safe_add(e, olde);
        }
        return Array(a, b, c, d, e);

    }

    /*
     *   Perform   the   appropriate   triplet   combination   function   for   the   current
     *   iteration
     */
    function sha1_ft(t, b, c, d) {
        if (t < 20)
            return (b & c) | ((~b) & d);
        if (t < 40)
            return b ^ c ^ d;
        if (t < 60)
            return (b & c) | (b & d) | (c & d);
        return b ^ c ^ d;
    }

    /*
     *   Determine   the   appropriate   additive   constant   for   the   current   iteration
     */
    function sha1_kt(t) {
        return (t < 20) ? 1518500249 : (t < 40) ? 1859775393 : (t < 60) ? -1894007588 : -899497514;
    }

    /*
     *   Calculate   the   HMAC-SHA1   of   a   key   and   some   data
     */
    function core_hmac_sha1(key, data) {
        var bkey = str2binb(key);
        if (bkey.length > 16)
            bkey = core_sha1(bkey, key.length * chrsz);

        var ipad = Array(16),
            opad = Array(16);
        for (var i = 0; i < 16; i++) {
            ipad[i] = bkey[i] ^ 0x36363636;
            opad[i] = bkey[i] ^ 0x5C5C5C5C;
        }

        var hash = core_sha1(ipad.concat(str2binb(data)), 512 + data.length * chrsz);
        return core_sha1(opad.concat(hash), 512 + 160);
    }

    /*
     *   Add   integers,   wrapping   at   2^32.   This   uses   16-bit   operations   internally
     *   to   work   around   bugs   in   some   JS   interpreters.
     */
    function safe_add(x, y) {
        var lsw = (x & 0xFFFF) + (y & 0xFFFF);
        var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
        return (msw << 16) | (lsw & 0xFFFF);
    }

    /*
     *   Bitwise   rotate   a   32-bit   number   to   the   left.
     */
    function rol(num, cnt) {
        return (num << cnt) | (num >>> (32 - cnt));
    }

    /*
     *   Convert   an   8-bit   or   16-bit   string   to   an   array   of   big-endian   words
     *   In   8-bit   function,   characters   >255   have   their   hi-byte   silently   ignored.
     */
    function str2binb(str) {
        var bin = Array();
        var mask = (1 << chrsz) - 1;
        for (var i = 0; i < str.length * chrsz; i += chrsz)
            bin[i >> 5] |= (str.charCodeAt(i / chrsz) & mask) << (24 - i % 32);
        return bin;
    }

    /*
     *   Convert   an   array   of   big-endian   words   to   a   string
     */
    function binb2str(bin) {
        var str = "";
        var mask = (1 << chrsz) - 1;
        for (var i = 0; i < bin.length * 32; i += chrsz)
            str += String.fromCharCode((bin[i >> 5] >>> (24 - i % 32)) & mask);
        return str;
    }

    /*
     *   Convert   an   array   of   big-endian   words   to   a   hex   string.
     */
    function binb2hex(binarray) {
        var hex_tab = hexcase ? "0123456789ABCDEF" : "0123456789abcdef";
        var str = "";
        for (var i = 0; i < binarray.length * 4; i++) {
            str += hex_tab.charAt((binarray[i >> 2] >> ((3 - i % 4) * 8 + 4)) & 0xF) + hex_tab.charAt((binarray[i >> 2] >> ((3 - i % 4) * 8)) & 0xF);
        }
        return str;
    }

    /*
     *   Convert   an   array   of   big-endian   words   to   a   base-64   string
     */
    function binb2b64(binarray) {
        var tab = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
        var str = "";
        for (var i = 0; i < binarray.length * 4; i += 3) {
            var triplet = (((binarray[i >> 2] >> 8 * (3 - i % 4)) & 0xFF) << 16) | (((binarray[i + 1 >> 2] >> 8 * (3 - (i + 1) % 4)) & 0xFF) << 8) | ((binarray[i + 2 >> 2] >> 8 * (3 - (i + 2) % 4)) & 0xFF);
            for (var j = 0; j < 4; j++) {
                if (i * 8 + j * 6 > binarray.length * 32)
                    str += b64pad;
                else
                    str += tab.charAt((triplet >> 6 * (3 - j)) & 0x3F);
            }
        }
        return str;
    }
    
    //网络实现
    //获取签名串
    function getSign(data, secret){
        data || (data = {});
        var keys = [];
        for(var k in data){
            keys.push(k);
        }
        keys.sort(function(a, b){
            return a > b ? 1: -1;
        });
        var signStr = secret;
        var val;
        for(var k in keys){
            val = data[keys[k]];
            if(/[\u4e00-\u9fa5]+/.test(val)){
                signStr += keys[k] + encodeURIComponent(val);
            }else if(val != undefined && val !== ""){
                signStr += keys[k] + val;
            }
            
        }
        signStr += secret;
        return hex_sha1(signStr);
    }
    
    function toast(msg,time,type){
        if(type!=2){
            layer.open({
                content: msg,
                style: 'background-color:#000; color:#ccc; border:none;opacity:0.1;',
                time: (time==null?4:time)
            });
        }else{
            layer.open({
                type: 2,
                content: msg,
                shadeClose: false
            });
        }
    }
	var reqUrl    = "https://wx.scsjgjj.com/mobileApp/api/getway.do";
    // var reqUrl    = "http://192.168.1.20:8084/mobileApp/api/getway.do" ;
    //var reqUrl    = "http://192.168.27.66:8088/mobileApp/api/getway.do";
    // var reqUrl ="http://192.168.29.197:9090/netface/mt/router";
    //var  reqUrl ="http://192.168.31.216:8080/msnet/mt/router";
    var appKey    = "e33ffsdf554asc973d83";
    var appSecret = "5f54faf4g5h4k5l7a783";
    var vRegx     = {
            "r": {
                "reg": [/.+/],
                "tip": "请输入{label}"
            },
            "d": {
                "reg": [/^\d{4}(\-|\/|\.)(0)?[1-12]{1}\1(0)?[1-31]{1}$/],
                "tip": "{label}不是有效的日期"
            },
            "e": {
                "reg": [/^\S+@\S+$/],
                "tip": "{label}不是有效Email地址"
            },
            "n": {
                "reg":[/\d+/],
                "tip":"{label}不是有效的数字"
            },
            "h": {
                "reg": [/(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?/],
                "tip": "{label}格式无效"
            },
            "p": {
                "reg": [/^(^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$)|(^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])((\d{4})|\d{3}[Xx])$)$/],
                "tip": "{label}格式无效"
            },
            "m":{
                "reg":[/^(1[3,5,6,8][0-9]{9})$/],
                "tip": "{label}格式无效"      
            },
            "fa":{
                "tip":"{label}只允许(英文字母、数字、下划线、英文句点)组合",
                "handler": function(id, val){
                    val = val.replace(/[A-Za-z]*[0-9]*_*@*.*\s*/g, "");
                    if(val) return false;
                    return true;
                }
            },
            "fa_en":{
                "tip":"{label}只允许(英文字母、数字)组合",
                "handler": function(id, val){
                    val = val.replace(/[A-Za-z0-9]/g, "");
                    if(val) return false;
                    return true;
                }
            },
            "zc\[[0-9]+\]":{
                "tip":"",
                "handler": function(id, val, valid){
                    var reg = /zc\[([0-9]+)\]/,max;
                    if(reg.test(valid)){
                        max = RegExp.$1;
                        if(val.length > max){
                            this.tip = "{label}不能超过" + max + "个字符";
                            return false;
                        }
                    }
                    return true;
                }
            },
            "zd\[[0-9]+\]":{
                "tip":"",
                "handler": function(id, val, valid){
                    var reg = /zd\[([0-9]+)\]/,min;
                    if(reg.test(valid)){
                        min = RegExp.$1;
                        if(val.length < min){
                            this.tip = "{label}长度不足" + min + "个字符";
                            return false;
                        }
                    }
                    return true;
                }
            }
        };
    
    function indexOf(ar, item){
        if(!ar || !item) return -1;
        var index = -1, reg;
        try{reg = new RegExp("^" + item + "$");}catch(e){};
        for(var i = 0, len = ar.length; i < len; i++){
            if(ar[i] === item){
                return i;
            }else if(reg && reg.test(ar[i])){
                return i;
            }
        }
        return -1;
    }
    /**
     * 验证的id容器
     *  验证某个表单元素，被验证的表单元素要求具备属性valid和msgid,
     *  valid指定验证内容，r-必输,d-日期,n-数字,e-邮件,h-网址,p-身份证,fa-用户名格式验证（只能是英文、数字、_、@等）,
     *  zc[n]最长不能超过N个字符,zd[n]最短不能少于N个字符
     * @param {Object} id
     */
    function doValid(id,isyzm){
        if (!id) return true;
        var ids, c ,
            t, valid = true;
        if (id.indexOf(",") > -1) {
            ids = id.split(",");
        } 
        ids || (ids = [id]);
        // 验证text textarea
        for (var i = 0, len = ids.length; i < len; i++) {
            c = $("#" + ids[i]);
            if(c.length == 0) continue;
            if(indexOf(['INPUT', 'TEXTAREA','SELECT'], c[0].nodeName) == -1){
                c = c.find("input,textarea,select");
            }
            c.each(function(index) {
                if(index==c.length-1&&isyzm){
                    valid=true;
                    return valid;
                }
                var v = $(this).attr("valid"), type = $(this).attr("type"),
                    val = $(this).val(), label = $(this).attr("label") || $(this).attr("placeholder");
                label || (label = "");
                if(type){
                    type = type.toLowerCase();
                    if(indexOf(['button', 'submit','image','reset'], type) > -1) return; //此类不做处理
                }
                if (v) {
                    v = v.split(",");
                    for (var p in vRegx) {
                        var arIndex = indexOf(v, p);
                        if (arIndex > -1) {
                            t = vRegx[p].reg;
                            if (t) {
                                for (var j = 0, l = t.length; j < l; j++) {
                                    if (!t[j].test(val)) {
                                        valid = false;
                                        break;
                                    }
                                }
                            } else {
                                t = vRegx[p].handler;
                                if (t && !t.call(vRegx[p], $(this).attr("id"), val, v[arIndex])) {
                                    valid = false;
                                }
                            }
                            if (!valid) {
                                var msgTip = "";
                                if(type=="file"||$(this).attr("dataType")=="file"){
                                    msgTip = vRegx[p].tip.replace("{label}", label);
                                    msgTip= msgTip.replace("输入","选择");
                                }else{
                                   msgTip = vRegx[p].tip.replace("{label}", label);
                                  
                                }
                                toast(msgTip);
                                break;
                            }
                        }
                    }
                    if (!valid) {
                        return false;
                    }
                }
            });
            if(!valid) return false;
        }
        return true;
    }
    /**
     * 获取参数值
     * @param {Object} ids
     */
    function getParams(ids){
        if (!ids) return {};
        if (ids.indexOf(",") > -1) {
            ids = ids.split(",");
        } else {
            ids = [ids];
        }
        var data = {},c;
        for (var i = 0, len = ids.length; i < len; i++) {
            c = $("#" + ids[i]);
            if(c.length == 0) continue;
            if(indexOf(['INPUT', 'TEXTAREA'], c[0].nodeName) == -1){
                c = c.find("input,textarea,select");
            }
            c.each(function() {
                var type = $(this).attr("type");
                var dataType = $(this).attr("dataType");
                if(type){
                    type = type.toLowerCase();
                    if(indexOf(['button', 'submit','image','reset'], type) > -1) return; //此类不做处理
                    if(indexOf(["file"], dataType) > -1) return;
                }
                var id = $(this).attr("id");
                if(!id) id = $(this).attr("name");
                if (!id&&($(this).is("input")||$(this).is("textarea")||$(this).is("select"))) {
                    throw new Error("元素的Id不能为空");
                }
                var val;
                if($("input[type='radio'][name='" + id + "']").length > 0){
                    val=  $("input[type='radio'][name='" + id + "']:checked").val()
                }else{
                    val = $(this).val();
                }
                data[id] = val;
            });
        }
        return data;
    }
    /**
     * 网络请求
     * @param {Object} pids
     *          请求的参数容器id
     * @param {Object} succ
     *          成功回调函数
     * @param {Object} fail
     *          失败回调函数
     * @param {Object} reqData
     *          请求的参数
     */
    function doSubmit(pids, reqData, succ, fail,netfail){
        reqData || (reqData = {});
        if(!reqData.method){
            $.toast("未传入请求方法"); 
            return;
        }
        var upFiles=reqData.files;
        delete reqData.files;
        reqData.v || (reqData.v = '1.0');
        if (doValid(pids)) {
			var data = getParams(pids);
            //解析url上的参数，转化为post提交
            $.extend(data, reqData);
            data["appkey"] = appKey;
            data["timestamp"] = Date.now();
            data["systemPlat"]=md.systemType;
            data["appVersion"]=md.appVersion;
			data["systemVersion"]=md.systemVersion;
            if(!data.isSign){
                data["sign"] = getSign(data, appSecret);
            }

            /*if(data.isSign==1){
               reqUrl="http://192.168.1.130:8080/test/index.jsp";
            }*/
            var headers = {};
            /*var sessionId = $.val("sessionId");

            if(sessionId){
				//if(md.systemType!="ios"){
				   //headers["Cookie"] = "NETFACE_SESSIONID=" + sessionId;
				 //  headers["Cookie"] = "JSESSIONID_MOBILEAPP=" + sessionId;
				//}
                var cookies = "JSESSIONID_MOBILEAPP=" + sessionId;
                var clusterCookie = $.val("clusterCookie");
                if(clusterCookie){
                    cookies+=";"+clusterCookie;//.split(";")[0];
                }
                headers["Cookie"]=cookies;
            }*/

            var clusterCookie = $.val("clusterCookie");
            if (clusterCookie) {
                headers["Cookie"] = clusterCookie;

            }

            if(reqData.toast!=0){
                layer.open({
                    type: 2,
                    content: '数据获取中....',
                    shadeClose: false
                });
            }

            var sendData={values:data};
            if(upFiles){
                sendData.files=upFiles;
            }

            md.ajax({
                url: reqUrl,
				timeout:40,
                method: "post",
                data: sendData,
                headers:headers,returnAll:true
            },function(ret, err){
                //alert(JSON.stringify(ret.headers["Set-Cookie"]));
                //alert(JSON.stringify(err))
                if(err!=null){
                    $.closeToast();
                    if(reqData.toast!=0){
                      $.toast("网络不给力,请稍后尝试");
                      
                    }
                    if(netfail)netfail();  
                    //return;
                }
                if(ret&&ret.headers){
                    $.val("clusterCookie", ret.headers["Set-Cookie"]);

                }
                 if(ret&&ret.body){
                    var data = ret.body;
                    $.closeToast();
                    $.val("sessionId", data.sessionId);
                    if(data.rescode == '1'){
                        if(succ){
                           var mylist=[];
                           //如果data.list不为空且不是数组，则转换为数组
                           if(data.list&&!(data.list instanceof Array)){
                             mylist[0]=data.list;
                             data.list=mylist;  
                           } 
                            succ(data);
                         };
                    }else if(data.rescode == '3'){ //需要登录 ,跳转到登录页面
                        $.toast("请登录后办理此业务");
                        setTimeout(function(){
                            $.remove("userInfo_data");
                            $.remove("loginFlag");
                            $.remove("sessionId");
                            $.openWin("login.html","",false,true);
                        },2000)
                    }else if(data.rescode == '2'){ //api已过期，需要升级
                        updateApp(1,data);
                    }else if(data.rescode == '4'){//登录失效清空填充的用户信息
                        $.remove("userInfo_data");
                        $.remove("loginFlag");
                        $.remove("sessionId");
                        succ(data);
                    }else{
                        if(fail)fail(data);
                    }
                }
            });
        }
    }
    /**
     * 模版渲染函数
     * @param str
     * @param o
     * @returns
     */
    function tmpl2Str(str, o) {
        for (var k in o) {
            var re = new RegExp("{" + k + "}", "g");
            if(o[k] == undefined || o[k] == "null") o[k] = "";
            try{str = str.replace(re, o[k]);}catch(e){}
        }
        str = str.replace(/{.*}/, "");
        return str;
    }
    function updateApp(ele,mydata){
        if (ele==1&&md.systemType != 'android') { //调用api是检测是不是苹果提示升级
          //md.toast({msg:'发现新版本，请到appstore下载更新',duration:2000});
          if(mydata==null){return;}
          msg="发现新版本，需要升级才能办理相关业务";
          btns= ['确定', '取消']
          if(mydata.upmsg){
             msg=mydata.upmsg;
          }
          if(mydata.force==1){
            btns= ['确定'];
          }
          md.confirm({
                        title: '提示',
                        msg: msg,
                        buttons:btns
                  },function( ret, err ){
                     if(ret.buttonIndex==1){
                         if(mydata.iosId!=null){
                             md.openApp({
                                iosUrl: 'itms-apps://itunes.apple.com/cn/app/id'+mydata.iosId
                             });
                         }
                         if(mydata.iosurl!=null){
                             md.openApp({
                                iosUrl: mydata.iosurl
                             });
                         }
                     }
                  });

          return;
        }
        var os = 1;
        if(md.systemType != 'android'){
            os=2;
        }
        if(ele){
            ele.find(".lv_subTitle").html("检测中...<div class='fa fa-refresh fa-spin ulev2 sc-text'></div>");
        }
        var params =  {toast:0,"method": "user.version", "v": "1.0", "os": os};
        doSubmit(null,params,function(data){
            //alert(JSON.stringify(data))
            if(data.vername!=null&&md.appVersion != data.vername){
                  //data.url="http://m.cdzfgjj.gov.cn/cdnt/weixin/apk/cdzfgjj.apk";
                  md.confirm({
                        title: '提示',
                        msg: '发现新版本，需要升级才能办理相关业务',
                        buttons: ['确定', '取消']
                  },function( ret, err ){
                       if(ret.buttonIndex==1){
                            md.showProgress({
                                content: '正在升级，请稍等...',
                                modal: true
                            });
                           var dp={url:data.url,cache:false,savePath:"fs://fund.apk"};
                           md.download(dp,function(ret, err){
                              if(ret.state==2){
                                 $.toast("下载失败");
                                 md.cancelDownload({url:data.url})
                                 md.hideProgress();
                              }else if(ret.state==1){
                                md.hideProgress();
                                md.installApp({appUri:ret.savePath});
                              }
                           });
                           ele.find(".lv_subTitle").html("正在下载...<div class='fa fa-refresh fa-spin ulev2 sc-text'></div>");
                       }else{
                        ele.find(".lv_subTitle").html("");
                       }
                  });
            }else{
                if(ele){
                    ele.find(".lv_subTitle").html("已是最新版本");
                }
            }
        }); 
    }
    $.extend({
         doSubmit: doSubmit,
         doValid: doValid,
         tmpl2Str: tmpl2Str,
         updateApp:updateApp,
         toast: toast
    });
})(jQuery);